==> haskell-universe-base-1.1.4-96-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-universe-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 universe-base
version:              1.1.4
visibility:           public
id:                   universe-base-1.1.4-J5jM2l3KqGtJGPnEqMinJ2
key:                  universe-base-1.1.4-J5jM2l3KqGtJGPnEqMinJ2
license:              BSD-3-Clause
copyright:            2014 Daniel Wagner
maintainer:           me@dmwit.com
author:               Daniel Wagner
homepage:             https://github.com/dmwit/universe
synopsis:             A class for finite and recursively enumerable types.
description:
    A class for finite and recursively enumerable types and some helper functions for enumerating them.

    @
    class Universe a where universe :: [a]
    class Universe a => Finite a where universeF :: [a]; universeF = universe
    @

    This is slim package definiting only the type-classes and instances
    for types in GHC boot libraries.
    For more instances check @universe-instances-*@ packages.

category:             Data
abi:                  813a8b7b7fdc3e1f12d7a65295a12b0c
exposed:              True
exposed-modules:
    Data.Universe.Class Data.Universe.Generic Data.Universe.Helpers

import-dirs:          /usr/lib/ghc-9.4.8/site-local/universe-base-1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/universe-base-1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/universe-base-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-universe-base
hs-libraries:         HSuniverse-base-1.1.4-J5jM2l3KqGtJGPnEqMinJ2
depends:
    base-4.17.2.1 containers-0.6.7 tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-universe-base/html/universe-base.haddock

haddock-html:         /usr/share/doc/haskell-universe-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-universe-base-1.1.4-97-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-universe-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 universe-base
version:              1.1.4
visibility:           public
id:                   universe-base-1.1.4-9WqqYi3fxt8GcibC5DKj9P
key:                  universe-base-1.1.4-9WqqYi3fxt8GcibC5DKj9P
license:              BSD-3-Clause
copyright:            2014 Daniel Wagner
maintainer:           me@dmwit.com
author:               Daniel Wagner
homepage:             https://github.com/dmwit/universe
synopsis:             A class for finite and recursively enumerable types.
description:
    A class for finite and recursively enumerable types and some helper functions for enumerating them.

    @
    class Universe a where universe :: [a]
    class Universe a => Finite a where universeF :: [a]; universeF = universe
    @

    This is slim package definiting only the type-classes and instances
    for types in GHC boot libraries.
    For more instances check @universe-instances-*@ packages.

category:             Data
abi:                  cca29e14b6bf155cc96a984e93a792e4
exposed:              True
exposed-modules:
    Data.Universe.Class Data.Universe.Generic Data.Universe.Helpers

import-dirs:          /usr/lib/ghc-9.4.8/site-local/universe-base-1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/universe-base-1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/universe-base-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-universe-base
hs-libraries:         HSuniverse-base-1.1.4-9WqqYi3fxt8GcibC5DKj9P
depends:
    base-4.17.2.1 containers-0.6.7 tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-universe-base/html/universe-base.haddock

haddock-html:         /usr/share/doc/haskell-universe-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
